==> owncloud-9.0.3.tgz: owncloud/settings/l10n/nn_NO.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Deling",
    "Cron" : "Cron",
    "Log" : "Logg",
    "Language changed" : "Språk endra",
    "Invalid request" : "Ugyldig førespurnad",
    "Authentication error" : "Autentiseringsfeil",
    "Admins can't remove themself from the admin group" : "Administratorar kan ikkje fjerna seg sjølve frå admin-gruppa",
    "Unable to add user to group %s" : "Klarte ikkje leggja til brukaren til gruppa %s",
    "Unable to remove user from group %s" : "Klarte ikkje fjerna brukaren frå gruppa %s",
    "Couldn't update app." : "Klarte ikkje oppdatera programmet.",
    "Wrong password" : "Feil passord",
    "No user supplied" : "Ingen brukar gjeve",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Ver venleg og gje eit admingjenopprettingspassord, elles vil all brukardata gå tapt.",
    "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
    "Unable to change password" : "Klarte ikkje å endra passordet",
    "Email sent" : "E-post sendt",
    "Email saved" : "E-postadresse lagra",
    "All" : "Alle",
    "Please wait...." : "Ver venleg og vent …",
    "Error while disabling app" : "Klarte ikkje å skru av programmet",
    "Disable" : "Slå av",
    "Enable" : "Slå på",
    "Error while enabling app" : "Klarte ikkje å skru på programmet",
    "Updating...." : "Oppdaterer …",
    "Error while updating app" : "Feil ved oppdatering av app",
    "Updated" : "Oppdatert",
    "Delete" : "Slett",
    "Select a profile picture" : "Vel eit profilbilete",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "Groups" : "Grupper",
    "undo" : "angra",
    "never" : "aldri",
    "add group" : "legg til gruppe",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord",
    "__language_name__" : "Nynorsk",
    "Login" : "Logg inn",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-modulen «fileinfo» manglar. Me rår sterkt til å slå på denne modulen for å best mogleg oppdaga MIME-typar.",
    "Allow apps to use the Share API" : "La app-ar bruka API-et til deling",
    "Allow public uploads" : "Tillat offentlege opplastingar",
    "Allow resharing" : "Tillat vidaredeling",
    "Execute one task with each page loaded" : "Utfør éi oppgåve for kvar sidelasting",
    "Encryption" : "Kryptering",
    "Server address" : "Tenaradresse",
    "More" : "Meir",
    "Less" : "Mindre",
    "Version" : "Utgåve",
    "Forum" : "Forum",
    "Profile picture" : "Profilbilete",
    "Upload new" : "Last opp ny",
    "Remove image" : "Fjern bilete",
    "Cancel" : "Avbryt",
    "Email" : "E-post",
    "Your email address" : "Di epost-adresse",
    "Password" : "Passord",
    "Unable to change your password" : "Klarte ikkje endra passordet",
    "Current password" : "Passord",
    "New password" : "Nytt passord",
    "Change password" : "Endra passord",
    "Language" : "Språk",
    "Help translate" : "Hjelp oss å omsetja",
    "Get the apps to sync your files" : "Få app-ar som kan synkronisera filene dine",
    "Show First Run Wizard again" : "Vis Oppstartvegvisaren igjen",
    "Username" : "Brukarnamn",
    "Create" : "Lag",
    "Admin Recovery Password" : "Gjenopprettingspassord for administrator",
    "Enter the recovery password in order to recover the users files during password change" : "Skriv inn gjenopprettingspassordet brukt for å gjenoppretta brukarfilene ved passordendring",
    "Group" : "Gruppe",
    "Unlimited" : "Ubegrensa",
    "Other" : "Anna",
    "Quota" : "Kvote",
    "set new password" : "lag nytt passord",
    "Default" : "Standard"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.3.tgz: owncloud/settings/l10n/nn_NO.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Feil passord",
    "No user supplied" : "Ingen brukar gjeve",
    "Authentication error" : "Autentiseringsfeil",
    "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
    "Unable to change password" : "Klarte ikkje å endra passordet",
    "Couldn't send reset email. Please contact your administrator." : "Kunne ikkje senda e-post for nullstilling, kontakt administratoren.",
    "Federated Cloud Sharing" : "Klarert sky deling",
    "Email sent" : "E-post sendt",
    "__language_name__" : "Nynorsk",
    "Language changed" : "Språk endra",
    "Invalid request" : "Ugyldig førespurnad",
    "Admins can't remove themself from the admin group" : "Administratorar kan ikkje fjerna seg sjølve frå admin-gruppa",
    "All" : "Alle",
    "Please wait...." : "Ver venleg og vent …",
    "Error while disabling app" : "Klarte ikkje å skru av programmet",
    "Disable" : "Slå av",
    "Enable" : "Slå på",
    "Error while enabling app" : "Klarte ikkje å skru på programmet",
    "Updating...." : "Oppdaterer …",
    "Error while updating app" : "Feil ved oppdatering av app",
    "Updated" : "Oppdatert",
    "Delete" : "Slett",
    "Select a profile picture" : "Vel eit profilbilete",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "OK passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "undo" : "angra",
    "never" : "aldri",
    "add group" : "legg til gruppe",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord",
    "Cheers!" : "Skål!",
    "Forum" : "Forum",
    "Cron" : "Cron",
    "Open documentation" : "Opne dokumentasjon.",
    "Execute one task with each page loaded" : "Utfør éi oppgåve for kvar sidelasting",
    "Sharing" : "Deling",
    "Allow apps to use the Share API" : "La app-ar bruka API-et til deling",
    "Allow public uploads" : "Tillat offentlege opplastingar",
    "days" : "dagar",
    "Allow resharing" : "Tillat vidaredeling",
    "Log" : "Logg",
    "None" : "Ingen",
    "Login" : "Logg inn",
    "Encryption" : "Kryptering",
    "Server address" : "Tenaradresse",
    "Port" : "Port",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-modulen «fileinfo» manglar. Me rår sterkt til å slå på denne modulen for å best mogleg oppdaga MIME-typar.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Spesielt ved bruk av klient for å synkronisera bør ein ikkje bruka SQLite.",
    "Get the apps to sync your files" : "Få app-ar som kan synkronisera filene dine",
    "Show First Run Wizard again" : "Vis Oppstartvegvisaren igjen",
    "Profile picture" : "Profilbilete",
    "Upload new" : "Last opp ny",
    "Remove image" : "Fjern bilete",
    "Cancel" : "Avbryt",
    "Email" : "E-post",
    "Your email address" : "Di epost-adresse",
    "Password" : "Passord",
    "Unable to change your password" : "Klarte ikkje endra passordet",
    "Current password" : "Passord",
    "New password" : "Nytt passord",
    "Change password" : "Endra passord",
    "Language" : "Språk",
    "Help translate" : "Hjelp oss å omsetja",
    "Unlimited" : "Ubegrensa",
    "Name" : "Namn",
    "Username" : "Brukarnamn",
    "Version" : "Utgåve",
    "Personal" : "Personleg",
    "Admin" : "Admin",
    "Error" : "Feil",
    "E-Mail" : "E-post",
    "Create" : "Lag",
    "Admin Recovery Password" : "Gjenopprettingspassord for administrator",
    "Enter the recovery password in order to recover the users files during password change" : "Skriv inn gjenopprettingspassordet brukt for å gjenoppretta brukarfilene ved passordendring",
    "Group" : "Gruppe",
    "Other" : "Anna",
    "Quota" : "Kvote",
    "set new password" : "lag nytt passord",
    "Default" : "Standard"
},
"nplurals=2; plural=(n != 1);");
